@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,15 +11,15 @@ func AsanaClientID() *config.Rule {
 	r := config.Rule{
 		Description: "Discovered a potential Asana Client ID, risking unauthorized access to Asana projects and sensitive task information.",
 		RuleID:      "asana-client-id",
-		Regex:       generateSemiGenericRegex([]string{"asana"}, numeric("16"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"asana"}, utils.Numeric("16"), true),
 		Keywords:    []string{"asana"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("asana", secrets.NewSecret(numeric("16"))),
+		utils.GenerateSampleSecret("asana", secrets.NewSecret(utils.Numeric("16"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
 
 func AsanaClientSecret() *config.Rule {
@@ -26,14 +27,14 @@ func AsanaClientSecret() *config.Rule {
 	r := config.Rule{
 		Description: "Identified an Asana Client Secret, which could lead to compromised project management integrity and unauthorized access.",
 		RuleID:      "asana-client-secret",
-		Regex:       generateSemiGenericRegex([]string{"asana"}, alphaNumeric("32"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"asana"}, utils.AlphaNumeric("32"), true),
 
 		Keywords: []string{"asana"},
 	}
 
 	// validate
 	tps := []string{
-		generateSampleSecret("asana", secrets.NewSecret(alphaNumeric("32"))),
+		utils.GenerateSampleSecret("asana", secrets.NewSecret(utils.AlphaNumeric("32"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
