@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,8 +11,8 @@ func CoinbaseAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "coinbase-access-token",
 		Description: "Detected a Coinbase Access Token, posing a risk of unauthorized access to cryptocurrency accounts and financial transactions.",
-		Regex: generateSemiGenericRegex([]string{"coinbase"},
-			alphaNumericExtendedShort("64"), true),
+		Regex: utils.GenerateSemiGenericRegex([]string{"coinbase"},
+			utils.AlphaNumericExtendedShort("64"), true),
 		Keywords: []string{
 			"coinbase",
 		},
@@ -19,8 +20,8 @@ func CoinbaseAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("coinbase",
-			secrets.NewSecret(alphaNumericExtendedShort("64"))),
+		utils.GenerateSampleSecret("coinbase",
+			secrets.NewSecret(utils.AlphaNumericExtendedShort("64"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
