@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func DroneciAccessToken() *config.Rule {
 	r := config.Rule{
 		RuleID:      "droneci-access-token",
 		Description: "Detected a Droneci Access Token, potentially compromising continuous integration and deployment workflows.",
-		Regex:       generateSemiGenericRegex([]string{"droneci"}, alphaNumeric("32"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"droneci"}, utils.AlphaNumeric("32"), true),
 
 		Keywords: []string{
 			"droneci",
@@ -19,7 +20,7 @@ func DroneciAccessToken() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("droneci", secrets.NewSecret(alphaNumeric("32"))),
+		utils.GenerateSampleSecret("droneci", secrets.NewSecret(utils.AlphaNumeric("32"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
