@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func Prefect() *config.Rule {
 	r := config.Rule{
 		RuleID:      "prefect-api-token",
 		Description: "Detected a Prefect API token, risking unauthorized access to workflow management and automation services.",
-		Regex:       generateUniqueTokenRegex(`pnu_[a-z0-9]{36}`, true),
+		Regex:       utils.GenerateUniqueTokenRegex(`pnu_[a-z0-9]{36}`, true),
 
 		Keywords: []string{
 			"pnu_",
@@ -19,7 +20,7 @@ func Prefect() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("api-token", "pnu_"+secrets.NewSecret(alphaNumeric("36"))),
+		utils.GenerateSampleSecret("api-token", "pnu_"+secrets.NewSecret(utils.AlphaNumeric("36"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
