@@ -1,6 +1,7 @@
 package rules
 
 import (
+	"github.com/zricethezav/gitleaks/v8/cmd/generate/config/utils"
 	"github.com/zricethezav/gitleaks/v8/cmd/generate/secrets"
 	"github.com/zricethezav/gitleaks/v8/config"
 )
@@ -10,7 +11,7 @@ func ZendeskSecretKey() *config.Rule {
 	r := config.Rule{
 		RuleID:      "zendesk-secret-key",
 		Description: "Detected a Zendesk Secret Key, risking unauthorized access to customer support services and sensitive ticketing data.",
-		Regex:       generateSemiGenericRegex([]string{"zendesk"}, alphaNumeric("40"), true),
+		Regex:       utils.GenerateSemiGenericRegex([]string{"zendesk"}, utils.AlphaNumeric("40"), true),
 		Keywords: []string{
 			"zendesk",
 		},
@@ -18,7 +19,7 @@ func ZendeskSecretKey() *config.Rule {
 
 	// validate
 	tps := []string{
-		generateSampleSecret("zendesk", secrets.NewSecret(alphaNumeric("40"))),
+		utils.GenerateSampleSecret("zendesk", secrets.NewSecret(utils.AlphaNumeric("40"))),
 	}
-	return validate(r, tps, nil)
+	return utils.Validate(r, tps, nil)
 }
